@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Getopt::Long with Class - ~/lib/Getopt/Class.pm
-## Version v0.103.1
+## Version v0.103.2
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/04/25
-## Modified 2022/10/24
+## Modified 2022/10/26
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -26,7 +26,7 @@ BEGIN
     use Module::Generic::Scalar;
     use Nice::Try;
     use Scalar::Util;
-    our $VERSION = 'v0.103.1';
+    our $VERSION = 'v0.103.2';
 };
 
 use strict;
@@ -467,85 +467,9 @@ sub postprocess
         
         if( ( $def->{type} eq 'date' || $def->{type} eq 'datetime' ) && length( $opts->{ $k } ) )
         {
-            my( $dt, $tz );
-            # DateTime::TimeZone::Local will die ungracefully if the local timezeon is not set with the error:
-            # "Cannot determine local time zone"
-            try
-            {
-                require DateTime::TimeZone;
-                $tz = DateTime::TimeZone->new( name => 'local' );
-            }
-            catch( $e )
-            {
-                $tz = DateTime::TimeZone->new( name => 'UTC' );
-                my $class = ref( $self ) || $self;
-                warn( "Your system is missing key timezone components. ${class}::_parse_timestamp is reverting to UTC instead of local time zone.\n" );
-            }
-            if( $opts->{ $k } =~ /^\d+$/ )
-            {
-                try
-                {
-                    $dt = DateTime->from_epoch( epoch => $opts->{ $k } );
-                }
-                catch( $e )
-                {
-                    return( $self->error( "An unexpected error occurred while converting date provided for \"$k\" (", $opts->{ $k }, "): $e" ) );
-                }
-            }
-            elsif( $def->{type} eq 'date' && $opts->{ $k } =~ /^(?<year>\d{4})-(?<month>\d{1,2})-(?<day>\d{1,2})$/ )
-            {
-                try
-                {
-                    $dt = DateTime->new(
-                        year => int( $+{year} ),
-                        month => int( $+{month} ),
-                        day => int( $+{day} ),
-                        hour => 0,
-                        minute => 0,
-                        second => 0,
-                        time_zone => $tz,
-                    );
-                }
-                catch( $e )
-                {
-                    return( $self->error( "An unexpected error occurred while converting date provided for \"$k\" (", $opts->{ $k }, "): $e" ) );
-                }
-            }
-            elsif( $def->{type} eq 'datetime' && $opts->{ $k } =~ /^(?<year>\d{4})-(?<month>\d{1,2})-(?<day>\d{1,2})(?:T|\s)(?<hour>\d{1,2})\:(?<minute>\d{1,2})\:(?<second>\d{1,2})$/ )
-            {
-                try
-                {
-                    $dt = DateTime->new(
-                        year => int( $+{year} ),
-                        month => int( $+{month} ),
-                        day => int( $+{day} ),
-                        hour => int( $+{hour} ),
-                        minute => int( $+{minute} ),
-                        second => int( $+{second} ),
-                        time_zone => 'local',
-                    );
-                }
-                catch( $e )
-                {
-                    return( $self->error( "An unexpected error occurred while converting date provided for \"$k\" (", $opts->{ $k }, "): $e" ) );
-                }
-            }
-            elsif( $opts->{ $k } eq 'now' || $opts->{ $k } eq 'today' )
-            {
-                $dt = DateTime->now( time_zone => $tz );
-            }
-            else
-            {
-                return( $self->error( "Unsuported value for date or datetime \"$k\": ", $opts->{ $k }, ". Please use a unix timestamp (i.e. an integer) or an iso 8601 type like 2019-12-25 or 2019-12-25T07:30:10" ) );
-            }
-            # Default format for stringification is the unix timestamp
-            my $fmt = DateTime::Format::Strptime->new(
-                pattern => '%s',
-                locale => 'en_GB',
-                time_zone => $tz,
-            );
-            $dt->set_formatter( $fmt );
-            $opts->{ $k } = $dt;
+            my $dt = $self->_parse_timestamp( $opts->{ $k } );
+            return( $self->pass_error ) if( !defined( $dt ) );
+            $opts->{ $k } = $dt if( $dt );
         }
         elsif( $def->{type} eq 'array' )
         {
@@ -1088,7 +1012,7 @@ Getopt::Class - Extended dictionary version of Getopt::Long
 
 =head1 VERSION
 
-    v0.103.1
+    v0.103.2
 
 =head1 DESCRIPTION
 
